==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/Lek.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.JednostkaPojemnosciOpakowania;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class Lek extends GenericDPSObject {
    /**
     * LEK.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * LEK.DAWKA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String dawka;

    /**
     * LEK.NAZWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nazwa;

    /**
     * LEK.OPAKOWANIE_JEDNOSTKA_POJEMNOSCI
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private JednostkaPojemnosciOpakowania opakowanieJednostkaPojemnosci;

    /**
     * LEK.POSTAC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String postac;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return LEK.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * LEK.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return LEK.DAWKA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getDawka() {
        return dawka;
    }

    /**
     * LEK.DAWKA
     *
     * @param dawka
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDawka(String dawka) {
        this.dawka = dawka == null ? null : dawka.trim();
    }

    /**
     * @return LEK.NAZWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * LEK.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return LEK.OPAKOWANIE_JEDNOSTKA_POJEMNOSCI
     * @mbggenerated 2014-03-10 10:45:37
     */
    public JednostkaPojemnosciOpakowania getOpakowanieJednostkaPojemnosci() {
        return opakowanieJednostkaPojemnosci;
    }

    /**
     * LEK.OPAKOWANIE_JEDNOSTKA_POJEMNOSCI
     *
     * @param opakowanieJednostkaPojemnosci
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOpakowanieJednostkaPojemnosci(JednostkaPojemnosciOpakowania opakowanieJednostkaPojemnosci) {
        this.opakowanieJednostkaPojemnosci = opakowanieJednostkaPojemnosci;
    }

    /**
     * @return LEK.POSTAC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getPostac() {
        return postac;
    }

    /**
     * LEK.POSTAC
     *
     * @param postac
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPostac(String postac) {
        this.postac = postac == null ? null : postac.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Lek other = (Lek) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDawka() == null ? other.getDawka() == null : this.getDawka().equals(other.getDawka()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getOpakowanieJednostkaPojemnosci() == null ? other.getOpakowanieJednostkaPojemnosci() == null : this.getOpakowanieJednostkaPojemnosci().equals(other.getOpakowanieJednostkaPojemnosci()))
            && (this.getPostac() == null ? other.getPostac() == null : this.getPostac().equals(other.getPostac()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDawka() == null) ? 0 : getDawka().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getOpakowanieJednostkaPojemnosci() == null) ? 0 : getOpakowanieJednostkaPojemnosci().hashCode());
        result = prime * result + ((getPostac() == null) ? 0 : getPostac().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dawka=").append(dawka);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", opakowanieJednostkaPojemnosci=").append(opakowanieJednostkaPojemnosci);
        sb.append(", postac=").append(postac);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/Lek.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.JednostkaPojemnosciOpakowania;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class Lek extends GenericDPSObject {
    /**
     * LEK.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * LEK.DAWKA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String dawka;

    /**
     * LEK.NAZWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nazwa;

    /**
     * LEK.OPAKOWANIE_JEDNOSTKA_POJEMNOSCI
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private JednostkaPojemnosciOpakowania opakowanieJednostkaPojemnosci;

    /**
     * LEK.POSTAC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String postac;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return LEK.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * LEK.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return LEK.DAWKA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getDawka() {
        return dawka;
    }

    /**
     * LEK.DAWKA
     *
     * @param dawka
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDawka(String dawka) {
        this.dawka = dawka == null ? null : dawka.trim();
    }

    /**
     * @return LEK.NAZWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * LEK.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return LEK.OPAKOWANIE_JEDNOSTKA_POJEMNOSCI
     * @mbggenerated 2014-03-13 16:02:38
     */
    public JednostkaPojemnosciOpakowania getOpakowanieJednostkaPojemnosci() {
        return opakowanieJednostkaPojemnosci;
    }

    /**
     * LEK.OPAKOWANIE_JEDNOSTKA_POJEMNOSCI
     *
     * @param opakowanieJednostkaPojemnosci
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOpakowanieJednostkaPojemnosci(JednostkaPojemnosciOpakowania opakowanieJednostkaPojemnosci) {
        this.opakowanieJednostkaPojemnosci = opakowanieJednostkaPojemnosci;
    }

    /**
     * @return LEK.POSTAC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getPostac() {
        return postac;
    }

    /**
     * LEK.POSTAC
     *
     * @param postac
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPostac(String postac) {
        this.postac = postac == null ? null : postac.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Lek other = (Lek) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDawka() == null ? other.getDawka() == null : this.getDawka().equals(other.getDawka()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getOpakowanieJednostkaPojemnosci() == null ? other.getOpakowanieJednostkaPojemnosci() == null : this.getOpakowanieJednostkaPojemnosci().equals(other.getOpakowanieJednostkaPojemnosci()))
            && (this.getPostac() == null ? other.getPostac() == null : this.getPostac().equals(other.getPostac()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDawka() == null) ? 0 : getDawka().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getOpakowanieJednostkaPojemnosci() == null) ? 0 : getOpakowanieJednostkaPojemnosci().hashCode());
        result = prime * result + ((getPostac() == null) ? 0 : getPostac().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dawka=").append(dawka);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", opakowanieJednostkaPojemnosci=").append(opakowanieJednostkaPojemnosci);
        sb.append(", postac=").append(postac);
        sb.append("]");
        return sb.toString();
    }
}
